@@ -27,12 +27,12 @@ else:
 import requests
 from dateutil.parser import parse as dateparse
 import click
-from click import echo, style
+from click import echo, style, echo_via_pager
 from click.termui import get_terminal_size
 
-__version__ = "0.3.2"
-__author__ = "Steven Loria"
-__license__ = "MIT"
+__version__ = '0.4.0'
+__author__ = 'Steven Loria'
+__license__ = 'MIT'
 
 DATE_FORMAT = "%y/%m/%d"
 MARGIN = 3
@@ -167,7 +167,7 @@ def browse(package, homepage):
 def format_result(result, name_column_width=25):
     name = result['name']
     summary_wrapped = textwrap.wrap(
-        result['summary'],
+        result['summary'] or name,
         width=click.get_terminal_size()[0] - name_column_width - MARGIN
     )
     padding = ' ' * (name_column_width + 3)
@@ -203,7 +203,7 @@ def search(query, n_results, web):
         searcher = Searcher()
         results = searcher.search(query, n=n_results)
         first_line = style('Search results for "{0}"\n'.format(query), bold=True)
-        echo(
+        echo_via_pager(
             first_line +
             '\n'.join([format_result(result) for result in results])
         )
